@@ -37,17 +37,23 @@
 #include <KPluginFactory>
 #include <KWindowSystem>
 #include <KDialog>
-#include <KWallet/Wallet>
-
 #include <KDebug>
+#include <KConfig>
+#include <KConfigGroup>
+#include <KWallet/Wallet>
+#include <QDebug>
 
-SecretAgent::SecretAgent(QObject* parent):
-    NetworkManager::SecretAgent("org.kde.networkmanagement", parent),
-    m_wallet(0),
-    m_dialog(0)
+SecretAgent::SecretAgent(QObject* parent)
+    : NetworkManager::SecretAgent("org.kde.networkmanagement", parent)
+    , m_openWalletFailed(false)
+    , m_wallet(0)
+    , m_dialog(0)
 {
     connect(NetworkManager::notifier(), SIGNAL(serviceDisappeared()),
             this, SLOT(killDialogs()));
+
+    // We have to import secrets previously stored in plaintext files
+    importSecretsFromPlainTextFiles();
 }
 
 SecretAgent::~SecretAgent()
@@ -248,9 +254,13 @@ void SecretAgent::killDialogs()
 void SecretAgent::walletOpened(bool success)
 {
     if (!success) {
+        m_openWalletFailed = true;
         m_wallet->deleteLater();
         m_wallet = 0;
+    } else {
+        m_openWalletFailed = false;
     }
+
     processNext();
 }
 
@@ -450,6 +460,13 @@ bool SecretAgent::useWallet() const
         return true;
     }
 
+    /* If opening of KWallet failed before, we should not try to open it again and
+     * we should return false instead */
+    if (m_openWalletFailed) {
+        m_openWalletFailed = false;
+        return false;
+    }
+
     if (KWallet::Wallet::isEnabled()) {
         m_wallet = KWallet::Wallet::openWallet(KWallet::Wallet::LocalWallet(), 0, KWallet::Wallet::Asynchronous);
         if (m_wallet) {
@@ -487,3 +504,72 @@ void SecretAgent::sendSecrets(const NMVariantMapMap &secrets, const QDBusMessage
         kWarning() << "Failed put the secret into the queue";
     }
 }
+
+void SecretAgent::importSecretsFromPlainTextFiles()
+{
+    KConfig config(QLatin1String("plasma-networkmanagement"), KConfig::SimpleConfig);
+
+    // No action is required when the list of secrets is empty
+    if (!config.groupList().isEmpty()) {
+        foreach (const QString &groupName, config.groupList()) {
+            QString loadedUuid = groupName.split(';').first().remove('{').remove('}');
+            QString loadedSettingType = groupName.split(';').last();
+            NetworkManager::Connection::Ptr connection = NetworkManager::findConnectionByUuid(loadedUuid);
+            if (connection) {
+                NetworkManager::Setting::SecretFlags secretFlags = KWallet::Wallet::isEnabled() ? NetworkManager::Setting::AgentOwned : NetworkManager::Setting::None;
+                QMap<QString, QString> secrets = config.entryMap(groupName);
+                NMVariantMapMap settings = connection->settings()->toMap();
+
+                foreach (const QString &setting, settings.keys()) {
+                    if (setting == QLatin1String("vpn")) {
+                        NetworkManager::VpnSetting::Ptr vpnSetting = connection->settings()->setting(NetworkManager::Setting::Vpn).staticCast<NetworkManager::VpnSetting>();
+                        if (vpnSetting) {
+                            // Add loaded secrets from the config file
+                            vpnSetting->secretsFromStringMap(secrets);
+
+                            NMStringMap vpnData = vpnSetting->data();
+                            // Reset flags, we can't save secrets to our secret agent when KWallet is not enabled, because
+                            // we dropped support for plaintext files, therefore they need to be stored to NetworkManager
+                            foreach (const QString &key, vpnData.keys()) {
+                                if (key.endsWith(QLatin1String("-flags"))) {
+                                    vpnData.insert(key, QString::number((int)secretFlags));
+                                }
+                            }
+
+                            vpnSetting->setData(vpnData);
+                            settings.insert(setting, vpnSetting->toMap());
+                            connection->update(settings);
+                        }
+                    } else {
+                        if (setting == loadedSettingType) {
+                            QVariantMap tmpSetting = settings.value(setting);
+                            // Reset flags, we can't save secrets to our secret agent when KWallet is not enabled, because
+                            // we dropped support for plaintext files, therefore they need to be stored to NetworkManager
+                            foreach (const QString &key, tmpSetting.keys()) {
+                                if (key.endsWith(QLatin1String("-flags"))) {
+                                    tmpSetting.insert(key, (int)secretFlags);
+                                }
+                            }
+
+                            // Add loaded secrets from the config file
+                            QMap<QString, QString>::const_iterator it = secrets.constBegin();
+                            QMap<QString, QString>::const_iterator end = secrets.constEnd();
+                            for (; it != end; ++it) {
+                                tmpSetting.insert(it.key(), it.value());
+                            }
+
+                            // Replace the old setting with the new one
+                            settings.insert(setting, tmpSetting);
+                            // Update the connection which re-saves secrets
+                            connection->update(settings);
+                        }
+                    }
+                }
+            }
+
+            // Remove the group
+            KConfigGroup group(&config, groupName);
+            group.deleteGroup();
+        }
+    }
+}
