@@ -3,6 +3,7 @@
     Copyright 2009 Will Stephenson <wstephenson@kde.org>
     Copyright 2012 Lamarque V. Souza <lamarque@kde.org>
     Copyright 2013 Lukas Tinkl <ltinkl@redhat.com>
+    Copyright 2013-2014 Jan Grulich <jgrulich@redhat.com>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -25,25 +26,33 @@
 #define PLASMANM_KDED_SERVICE_H
 
 #include <KDEDModule>
-#include <kdemacros.h>
+
+#include "plasmanm_export.h"
 
 #include <QVariant>
 
 class NetworkManagementServicePrivate;
 
-class KDE_EXPORT NetworkManagementService : public KDEDModule
+class PLASMA_NM_EXPORT NetworkManagementService : public KDEDModule
 {
+    Q_CLASSINFO("D-Bus Interface", "org.kde.plasmanetworkmanagement")
     Q_OBJECT
     Q_DECLARE_PRIVATE(NetworkManagementService)
 public:
     NetworkManagementService(QObject * parent, const QVariantList&);
     virtual ~NetworkManagementService();
-private Q_SLOTS:
-   void finishInitialization();
-private:
-    NetworkManagementServicePrivate * d_ptr;
 
-    void doInitialization();
+public Q_SLOTS:
+    Q_SCRIPTABLE void init();
+
+Q_SIGNALS:
+    Q_SCRIPTABLE void registered();
+
+private Q_SLOTS:
+    void slotRegistered(const QDBusObjectPath &path);
+
+private:
+    NetworkManagementServicePrivate * const d_ptr;
 };
 
 #endif // PLASMANM_KDED_SERVICE_H
