@@ -45,6 +45,7 @@
 #include <KService>
 #include <KServiceTypeTrader>
 #include <KWindowSystem>
+#include <KWallet/Wallet>
 
 Handler::Handler(QObject* parent)
     : QObject(parent)
@@ -52,7 +53,12 @@ Handler::Handler(QObject* parent)
     , m_tmpWimaxEnabled(NetworkManager::isWimaxEnabled())
     , m_tmpWirelessEnabled(NetworkManager::isWirelessEnabled())
     , m_tmpWwanEnabled(NetworkManager::isWwanEnabled())
+    , m_agentIface(QLatin1String("org.kde.kded"), QLatin1String("/modules/networkmanagement"),
+                   QLatin1String("org.kde.plasmanetworkmanagement"))
 {
+    initKdedModule();
+    QDBusConnection::sessionBus().connect(m_agentIface.service(), m_agentIface.path(), m_agentIface.interface(), QLatin1String("registered"),
+                                          this, SLOT(initKdedModule()));
 }
 
 Handler::~Handler()
@@ -160,7 +166,9 @@ void Handler::addAndActivateConnection(const QString& device, const QString& spe
         if (securityType == NetworkManager::Utils::StaticWep) {
             wifiSecurity->setKeyMgmt(NetworkManager::WirelessSecuritySetting::Wep);
             wifiSecurity->setWepKey0(password);
-            wifiSecurity->setWepKeyFlags(NetworkManager::Setting::AgentOwned);
+            if (KWallet::Wallet::isEnabled()) {
+                wifiSecurity->setWepKeyFlags(NetworkManager::Setting::AgentOwned);
+            }
         } else {
             if (ap->mode() == NetworkManager::AccessPoint::Adhoc) {
                 wifiSecurity->setKeyMgmt(NetworkManager::WirelessSecuritySetting::WpaNone);
@@ -168,7 +176,9 @@ void Handler::addAndActivateConnection(const QString& device, const QString& spe
                 wifiSecurity->setKeyMgmt(NetworkManager::WirelessSecuritySetting::WpaPsk);
             }
             wifiSecurity->setPsk(password);
-            wifiSecurity->setPskFlags(NetworkManager::Setting::AgentOwned);
+            if (KWallet::Wallet::isEnabled()) {
+                wifiSecurity->setPskFlags(NetworkManager::Setting::AgentOwned);
+            }
         }
         QDBusPendingReply<QDBusObjectPath> reply = NetworkManager::addAndActivateConnection(settings->toMap(), device, specificObject);
         QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(reply, this);
@@ -362,9 +372,14 @@ void Handler::editDialogAccepted()
     }
 }
 
+void Handler::initKdedModule()
+{
+    m_agentIface.call(QLatin1String("init"));
+}
+
 void Handler::replyFinished(QDBusPendingCallWatcher * watcher)
 {
-    QDBusPendingReply<QDBusObjectPath> reply = *watcher;
+    QDBusPendingReply<> reply = *watcher;
     if (reply.isError() || !reply.isValid()) {
         KNotification *notification = 0;
         QString error = reply.error().message();
