@@ -38,9 +38,9 @@ NetworkModel::NetworkModel(QObject* parent)
     roles[ConnectionIconRole] = "ConnectionIcon";
     roles[ConnectionPathRole] = "ConnectionPath";
     roles[ConnectionStateRole] = "ConnectionState";
+    roles[DeviceNameRole] = "DeviceName";
     roles[DevicePathRole] = "DevicePath";
     roles[DeviceStateRole] = "DeviceState";
-    roles[DownloadRole] = "Download";
     roles[DuplicateRole] = "Duplicate";
     roles[ItemUniqueNameRole] = "ItemUniqueName";
     roles[ItemTypeRole] = "ItemType";
@@ -58,7 +58,6 @@ NetworkModel::NetworkModel(QObject* parent)
     roles[TimeStampRole] = "TimeStamp";
     roles[TypeRole] = "Type";
     roles[UniRole] = "Uni";
-    roles[UploadRole] = "Upload";
     roles[UuidRole] = "Uuid";
     roles[VpnState] = "VpnState";
     setRoleNames(roles);
@@ -86,12 +85,12 @@ QVariant NetworkModel::data(const QModelIndex& index, int role) const
                 return item->connectionPath();
             case ConnectionStateRole:
                 return item->connectionState();
+            case DeviceNameRole:
+                return item->deviceName();
             case DevicePathRole:
                 return item->devicePath();
             case DeviceStateRole:
                 return item->deviceState();
-            case DownloadRole:
-                return item->download();
             case DuplicateRole:
                 return item->duplicate();
             case ItemUniqueNameRole:
@@ -130,8 +129,6 @@ QVariant NetworkModel::data(const QModelIndex& index, int role) const
                 return item->type();
             case UniRole:
                 return item->uni();
-            case UploadRole:
-                return item->upload();
             case UuidRole:
                 return item->uuid();
             case VpnState:
@@ -217,6 +214,8 @@ void NetworkModel::initializeSignals(const NetworkManager::Device::Ptr& device)
             SLOT(ipConfigChanged()), Qt::UniqueConnection);
     connect(device.data(), SIGNAL(ipV6ConfigChanged()),
             SLOT(ipConfigChanged()), Qt::UniqueConnection);
+    connect(device.data(), SIGNAL(ipInterfaceChanged()),
+            SLOT(ipInterfaceChanged()));
     connect(device.data(), SIGNAL(stateChanged(NetworkManager::Device::State,NetworkManager::Device::State,NetworkManager::Device::StateChangeReason)),
             SLOT(deviceStateChanged(NetworkManager::Device::State,NetworkManager::Device::State,NetworkManager::Device::StateChangeReason)), Qt::UniqueConnection);
 
@@ -356,9 +355,11 @@ void NetworkModel::addAvailableConnection(const QString& connection, const Netwo
             }
 
             NetworkManager::WirelessDevice::Ptr wifiDevice = device.objectCast<NetworkManager::WirelessDevice>();
-            NetworkManager::WirelessNetwork::Ptr wifiNetwork = wifiDevice->findNetwork(item->ssid());
-            if (wifiNetwork) {
-                updateFromWirelessNetwork(item, wifiNetwork);
+            if (wifiDevice) {
+                NetworkManager::WirelessNetwork::Ptr wifiNetwork = wifiDevice->findNetwork(item->ssid());
+                if (wifiNetwork) {
+                    updateFromWirelessNetwork(item, wifiNetwork);
+                }
             }
         }
 
@@ -433,8 +434,6 @@ void NetworkModel::addConnection(const NetworkManager::Connection::Ptr& connecti
 
         item->updateDetails();
 
-        connect(item, SIGNAL(itemUpdated()), SLOT(onItemUpdated()));
-
         const int index = m_list.count();
         beginInsertRows(QModelIndex(), index, index);
         m_list.insertItem(item);
@@ -486,8 +485,6 @@ void NetworkModel::addWimaxNsp(const NetworkManager::WimaxNsp::Ptr& nsp, const N
     item->setType(NetworkManager::ConnectionSettings::Wimax);
     item->updateDetails();
 
-    connect(item, SIGNAL(itemUpdated()), SLOT(onItemUpdated()));
-
     const int index = m_list.count();
     beginInsertRows(QModelIndex(), index, index);
     m_list.insertItem(item);
@@ -529,8 +526,6 @@ void NetworkModel::addWirelessNetwork(const NetworkManager::WirelessNetwork::Ptr
     item->setSecurityType(securityType);
     item->updateDetails();
 
-    connect(item, SIGNAL(itemUpdated()), SLOT(onItemUpdated()));
-
     const int index = m_list.count();
     beginInsertRows(QModelIndex(), index, index);
     m_list.insertItem(item);
@@ -557,8 +552,6 @@ void NetworkModel::checkAndCreateDuplicate(const QString& connection, const Netw
         NetworkModelItem * duplicatedItem = new NetworkModelItem(originalItem);
         duplicatedItem->updateDetails();
 
-        connect(duplicatedItem, SIGNAL(itemUpdated()), SLOT(onItemUpdated()));
-
         const int index = m_list.count();
         beginInsertRows(QModelIndex(), index, index);
         m_list.insertItem(duplicatedItem);
@@ -923,6 +916,7 @@ void NetworkModel::gsmNetworkSignalQualityChanged(uint signal)
         }
     }
 }
+
 #endif
 
 void NetworkModel::ipConfigChanged()
@@ -937,6 +931,20 @@ void NetworkModel::ipConfigChanged()
     }
 }
 
+void NetworkModel::ipInterfaceChanged()
+{
+    NetworkManager::Device * device = qobject_cast<NetworkManager::Device*>(sender());
+    if (device) {
+        foreach (NetworkModelItem * item, m_list.returnItems(NetworkItemsList::Device, device->uni())) {
+            if (device->ipInterfaceName().isEmpty()) {
+                item->setDeviceName(device->interfaceName());
+            } else {
+                item->setDeviceName(device->ipInterfaceName());
+            }
+        }
+    }
+}
+
 void NetworkModel::statusChanged(NetworkManager::Status status)
 {
     Q_UNUSED(status);
